@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Web::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::DuckPAN::Web::VERSION = '0.021';
+  $App::DuckPAN::Web::VERSION = '0.022';
 }
 
 use Moo;
@@ -84,7 +84,11 @@ sub request {
 						my $index = $_-1;
 						my $cap_from = '\$'.$_;
 						my $cap_to = $captures[$index];
-						$to =~ s/$cap_from/$cap_to/g;
+						if (defined $cap_to) {
+							$to =~ s/$cap_from/$cap_to/g;
+						} else {
+							$to =~ s/$cap_from//g;
+						}
 					}
 					p($to);
 					my $res = $self->ua->request(HTTP::Request->new(GET => $to));
@@ -175,7 +179,7 @@ App::DuckPAN::Web
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 AUTHOR
 
